==> haskell-base-orphans-0.5.4-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.5.4
id: base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
key: base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
license: MIT
copyright: (c) 2012-2016 Simon Hengel,
           (c) 2014-2016 João Cristóvão,
           (c) 2015-2016 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
abi: 8c3a56d4e360ead8f43a04032c64cc86
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/base-orphans-0.5.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/base-orphans-0.5.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/base-orphans-0.5.4
hs-libraries: HSbase-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.6-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.6
id: base-orphans-0.6-5PayU02PR2MEqN5xZtCkua
key: base-orphans-0.6-5PayU02PR2MEqN5xZtCkua
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
abi: f1beb4428fb94a36f0c3b7a12f70ed72
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/base-orphans-0.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/base-orphans-0.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/base-orphans-0.6
hs-libraries: HSbase-orphans-0.6-5PayU02PR2MEqN5xZtCkua
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
